@@ -20,9 +20,9 @@ return {
     date = date
   },
 documentation = [[\begin{document}
-The \code{date} package provides the \code{date} command, which simply
-outputs the date using the system's date function. You can customize
-the format by passing the \code{format} parameter, following the
+The \autodoc:package{date} package provides the \autodoc:command{\date} command, which simply
+outputs the date using the system’s date function. You can customize
+the format by passing the \autodoc:parameter{format} parameter, following the
 formatting codes in the Lua manual. (\url{https://www.lua.org/pil/22.1.html})
 \end{document}
 ]]
